@@ -12,11 +12,15 @@ from stochasticx.jobs.jobs import (
     TokenClassificationTask
 )
 from stochasticx.utils.parse_utils import print_table
-
+from stochasticx.utils.auth_utils import AuthUtils
+import sys
 
 @click.group(name="jobs")
 def jobs():
-    pass
+    try:
+        AuthUtils.get_auth_headers()
+    except:
+        sys.exit()
 
 @click.command(name="ls")
 def ls_jobs():
