@@ -1,4 +1,4 @@
-from stochasticx.constants.urls import DATASETS_URL
+from stochasticx.constants.urls import DATASETS_URL, LocalRoutes, get_local_url
 from stochasticx.utils.auth_utils import AuthUtils
 from stochasticx.utils.file_utils import DatasetUtils
 from stochasticx.utils.logging import configure_logger
@@ -137,7 +137,7 @@ class Dataset:
     def to_table(self):
         columns = ["Id", "Name", "Directory path", "Type", "Uploaded"]
         values = [
-            self.dataset_id,
+            str(self.dataset_id),
             self.name,
             self.directory_path,
             self.dataset_type,
@@ -240,4 +240,103 @@ class Datasets:
                     
                 return columns, values
 
-        return datasets
\ No newline at end of file
+        return datasets
+
+    
+    @staticmethod
+    def get_local_dataset(dataset_id: str):
+        """Get dataset by ID
+
+        Args:
+            dataset_id (str): ID
+
+        Returns:
+            Dataset: the dataset
+        """
+        url = get_local_url(LocalRoutes.DATASET_URL) + "/{}".format(dataset_id)
+
+        auth_header = None
+        response = requests.get(url, headers=auth_header)
+        dataset_data = response.json().get("data")
+
+        if dataset_data is not None:
+            ds = Dataset(
+                name=dataset_data.get("name"),
+                directory_path=dataset_data.get("path"),
+                dataset_type=dataset_data.get("type")
+            )
+            
+            ds.set_id(dataset_data.get("id"))
+            # ds.set_dataset_info(dataset_data.get("datasetInfo"))
+            # if dataset_data.get("datasetInfo") is not None:
+            #     ds.set_column_names(dataset_data.get("datasetInfo").get("column_names"))
+            ds.is_uploaded = True
+
+            return ds
+
+        return None
+    
+    @staticmethod
+    def get_local_datasets(fmt="table"):
+        """Gets all the datasets
+
+        Returns:
+            List[Dataset]: all the local datasets
+        """
+        datasets = []
+
+        # auth_header = AuthUtils.get_auth_headers()
+        auth_header = None
+        response = requests.get(get_local_url(LocalRoutes.DATASET_URL), headers=auth_header)
+        datasets_data = response.json().get("data")
+
+        if datasets_data is not None:
+            for dataset_data in datasets_data:
+                ds = Dataset(
+                    name=dataset_data.get("name"),
+                    directory_path=dataset_data.get("path"),
+                    dataset_type=dataset_data.get("type")
+                )
+                
+                ds.set_id(dataset_data.get("id"))
+                # ds.set_dataset_info(dataset_data.get("datasetInfo"))
+                # if dataset_data.get("datasetInfo") is not None:
+                #     ds.set_column_names(dataset_data.get("datasetInfo").get("column_names"))
+                ds.is_uploaded = True
+                
+                datasets.append(ds)
+
+            if fmt == "table":
+                columns = []
+                values = []
+                
+                if len(datasets) > 0:
+                    columns, _ = datasets[0].to_table()
+                    
+                for dataset in datasets:
+                    _, vals = dataset.to_table()
+                    values.append(vals)
+                    
+                return columns, values
+
+        return datasets
+
+
+    @staticmethod
+    def remove_local_dataset(dataset_id: str):
+        """Removes the local dataset
+
+        Args:
+            dataset_id (str): dataset ID
+
+        Returns:
+            None
+        """
+        
+        url = get_local_url(LocalRoutes.DATASET_URL) + "/{}".format(dataset_id)
+
+        auth_header = None
+        response = requests.delete(url, headers=auth_header)
+        status = response.json().get("data")
+        
+        return status
