@@ -1,4 +1,4 @@
-from stochasticx.constants.urls import MODELS_URL, OPTIMIZED_MODELS_URL
+from stochasticx.constants.urls import MODELS_URL, OPTIMIZED_MODELS_URL, LocalRoutes, get_local_url
 from stochasticx.utils.auth_utils import AuthUtils
 from stochasticx.utils.file_utils import ModelUtils
 import requests
@@ -110,7 +110,7 @@ class Model:
     def to_table(self):
         columns = ["Id", "Name", "Directory path", "Type", "Uploaded"]
         values = [
-            self.model_id,
+            str(self.model_id),
             self.name,
             self.directory_path,
             self.model_type,
@@ -240,6 +240,38 @@ class Models:
             return model
         
         return None
+
+    @staticmethod
+    def get_local_model(model_id: str):
+        """Gets the model from the Stochastic platform
+
+        Args:
+            model_id (str): model ID
+
+        Returns:
+            Model: model
+        """
+        
+        url = get_local_url(LocalRoutes.MODEL_URL) + "/{}".format(model_id)
+
+        auth_header = None
+        response = requests.get(url, headers=auth_header)
+        model_data = response.json().get("data")
+        
+        if model_data is not None:
+            model = Model(
+                name=model_data.get("name"),
+                directory_path=model_data.get("path"),
+                model_type=model_data.get("type")
+            )
+            
+            model.set_id(model_data.get("id"))
+            # model.set_model_info(model_data.get("modelInfo"))
+            model.is_uploaded = True
+            
+            return model
+        
+        return None
     
     @staticmethod
     def get_models(fmt=None):
@@ -283,7 +315,53 @@ class Models:
         return models
     
     @staticmethod
-    def get_optimized_models(fmt=None):
+    def get_local_models(fmt="table"):
+        """Gets all the models from the local registry
+
+        Returns:
+            List[Model]: list of models
+        """
+        models = []
+
+        # auth_header = AuthUtils.get_auth_headers()
+        auth_header = None
+        response = requests.get(get_local_url(LocalRoutes.MODEL_URL), headers=auth_header)
+        models_data = response.json().get("data")
+
+
+        if models_data is not None:
+            for model_data in models_data:
+
+                model = Model(
+                    name=model_data.get("name"),
+                    directory_path=model_data.get("path"),
+                    model_type=model_data.get("type")
+                )
+                
+                model.set_id(model_data.get("id"))
+                # model.set_model_info(model_data.get("modelInfo"))
+                model.is_uploaded = True
+                models.append(model)
+
+
+            if fmt == "table":
+                columns = []
+                values = []
+                
+                if len(models) > 0:
+                    columns, _ = models[0].to_table()
+                    
+                for model in models:
+                    _, vals = model.to_table()
+                    values.append(vals)
+                    
+                return columns, values
+
+        return models
+    
+
+    @staticmethod
+    def get_optimized_models(fmt="table"):
         """Gets all the optimized models from the Stochastic platform
 
         Returns:
@@ -326,6 +404,7 @@ class Models:
 
         return models
     
+    
     @staticmethod
     def get_optimized_model(model_id: str):
         """Gets an optimized model from the Stochastic plarform
@@ -354,4 +433,23 @@ class Models:
             
             return model
         
-        return None
\ No newline at end of file
+        return None
+
+    @staticmethod
+    def remove_local_model(model_id: str):
+        """Removes the local model
+
+        Args:
+            model_id (str): model ID
+
+        Returns:
+            None
+        """
+        
+        url = get_local_url(LocalRoutes.MODEL_URL) + "/{}".format(model_id)
+
+        auth_header = None
+        response = requests.delete(url, headers=auth_header)
+        status = response.json().get("data")
+        
+        return status
\ No newline at end of file
